summaryrefslogtreecommitdiffstats
path: root/kaddressbook/views/contactlistview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kaddressbook/views/contactlistview.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kaddressbook/views/contactlistview.h')
-rw-r--r--kaddressbook/views/contactlistview.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kaddressbook/views/contactlistview.h b/kaddressbook/views/contactlistview.h
index 7936333a..65c92702 100644
--- a/kaddressbook/views/contactlistview.h
+++ b/kaddressbook/views/contactlistview.h
@@ -17,8 +17,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef CONTACTLISTVIEW_H
@@ -41,10 +41,10 @@ class KIMProxy;
/** The whole tooltip design needs a lot of work. Currently it is
* hacked together to function.
*/
-class DynamicTip : public QToolTip
+class DynamicTip : public TQToolTip
{
public:
- DynamicTip( ContactListView * parent );
+ DynamicTip( ContactListView * tqparent );
protected:
void maybeTip( const TQPoint & );
@@ -56,11 +56,11 @@ class ContactListViewItem : public KListViewItem
{
public:
- ContactListViewItem(const KABC::Addressee &a, ContactListView* parent,
+ ContactListViewItem(const KABC::Addressee &a, ContactListView* tqparent,
KABC::AddressBook *doc, const KABC::Field::List &fields, KIMProxy *proxy );
const KABC::Addressee &addressee() const { return mAddressee; }
virtual void refresh();
- virtual ContactListView* parent();
+ virtual ContactListView* tqparent();
virtual TQString key ( int, bool ) const;
void setHasIM( bool hasIM );
/** Adds the border around the cell if the user wants it.
@@ -72,7 +72,7 @@ public:
private:
KABC::Addressee mAddressee;
KABC::Field::List mFields;
- ContactListView *parentListView;
+ ContactListView *tqparentListView;
KABC::AddressBook *mDocument;
KIMProxy *mIMProxy;
bool mHasIM;
@@ -85,11 +85,12 @@ private:
class ContactListView : public KListView
{
Q_OBJECT
+ TQ_OBJECT
public:
ContactListView(KAddressBookTableView *view,
KABC::AddressBook *doc,
- TQWidget *parent,
+ TQWidget *tqparent,
const char *name = 0L );
virtual ~ContactListView() {}
//void resort();
@@ -138,7 +139,7 @@ public:
protected:
/** Paints the background pixmap in the empty area. This method is needed
* since Qt::FixedPixmap will not scroll with the list view.
*/
virtual void paintEmptyArea( TQPainter * p, const TQRect & rect );
virtual void contentsMousePressEvent(TQMouseEvent*);
@@ -138,7 +139,7 @@ public:
protected:
/** Paints the background pixmap in the empty area. This method is needed
- * since Qt::FixedPixmap will not scroll with the list view.
+ * since TQt::FixedPixmap will not scroll with the list view.
*/
virtual void paintEmptyArea( TQPainter * p, const TQRect & rect );